@@ -1,7 +1,8 @@
 from .action_client import ActionClient, create_action_client
 from .flows_client import FlowsClient, create_flows_client
 from .graphviz_rendering import graphviz_format, state_colors_for_log
-from .token_management import get_access_token_for_scope, get_access_tokens_for_scopes
+from .queues_client import QueuesClient, create_queues_client
+from .token_management import get_authorizer_for_scope
 
 __version__ = "0.7.0"
 
@@ -10,8 +11,9 @@ __all__ = (
     "create_action_client",
     "FlowsClient",
     "create_flows_client",
-    "get_access_token_for_scope",
-    "get_access_tokens_for_scopes",
+    "QueuesClient",
+    "create_queues_client",
+    "get_authorizer_for_scope",
     "graphviz_format",
     "state_colors_for_log",
 )
