@@ -3,8 +3,12 @@ import uuid
 
 import typer
 
-from .callbacks import json_validator_callback, url_validator_callback
-from .helpers import format_and_echo, get_action_client_for_args, verbosity_option
+from globus_automate_client.action_client import create_action_client
+from globus_automate_client.cli.callbacks import (
+    json_validator_callback,
+    url_validator_callback,
+)
+from globus_automate_client.cli.helpers import format_and_echo, verbosity_option
 
 app = typer.Typer(short_help="Manage Globus Automate Actions")
 
@@ -27,7 +31,7 @@ def action_introspect(
     """
     Introspect an Action Provider's schema.
     """
-    ac = get_action_client_for_args(action_url, action_scope)
+    ac = create_action_client(action_url, action_scope)
     if ac is not None:
         result = ac.introspect()
         format_and_echo(result, verbose=verbose)
@@ -66,12 +70,10 @@ def action_run(
     """
     Launch an Action.
     """
-    ac = get_action_client_for_args(action_url, action_scope)
-    if ac is None:
-        typer.echo("Failed to get credentials. Was the scope provided?")
-    else:
-        body = json.loads(body)
-        result = ac.run(body, request_id)
+    ac = create_action_client(action_url, action_scope)
+    if ac:
+        parsed_body = json.loads(body)
+        result = ac.run(parsed_body, request_id)
         format_and_echo(result, verbose=verbose)
     return None
 
@@ -95,10 +97,8 @@ def action_status(
     """
     Query an Action's status by its ACTION_ID.
     """
-    ac = get_action_client_for_args(action_url, action_scope)
-    if ac is None:
-        typer.echo("Failed to get credentials. Was the scope provided?")
-    else:
+    ac = create_action_client(action_url, action_scope)
+    if ac:
         result = ac.status(action_id)
         format_and_echo(result, verbose=verbose)
     return None
@@ -123,10 +123,8 @@ def action_cancel(
     """
     Terminate a running Action by its ACTION_ID.
     """
-    ac = get_action_client_for_args(action_url, action_scope)
-    if ac is None:
-        typer.echo("Failed to get credentials. Was the scope provided?")
-    else:
+    ac = create_action_client(action_url, action_scope)
+    if ac:
         result = ac.cancel(action_id)
         format_and_echo(result, verbose=verbose)
     return None
@@ -151,10 +149,8 @@ def action_release(
     """
     Remove an Action's execution history by its ACTION_ID.
     """
-    ac = get_action_client_for_args(action_url, action_scope)
-    if ac is None:
-        typer.echo("Failed to get credentials. Was the scope provided?")
-    else:
+    ac = create_action_client(action_url, action_scope)
+    if ac:
         result = ac.release(action_id)
         format_and_echo(result, verbose=verbose)
     return None
