@@ -1,7 +1,7 @@
 import json
 import os
 import pathlib
-from typing import List
+from typing import List, Optional
 from urllib.parse import urlparse
 from uuid import UUID
 
@@ -34,6 +34,11 @@ def json_validator_callback(body: str) -> str:
     supplies a valid JSON or valid filename containing valid JSON. Returns the
     valid JSON string.
     """
+    # Callbacks are run regardless of whether an option was explicitly set.
+    # Handle the scenario where the default value for an option is empty
+    if not body:
+        return body
+
     # Reading from a file was indicated by prepending the filename with the @
     # symbol -- for backwards compatability check if the symbol is present and
     # remove it
@@ -50,7 +55,7 @@ def json_validator_callback(body: str) -> str:
             else:
                 body = json.dumps(json_body)
     elif body_path.exists() and body_path.is_dir():
-        raise typer.BadParameter(f"Expected file, received directory")
+        raise typer.BadParameter("Expected file, received directory")
     else:
         try:
             json.loads(body)
