@@ -3,10 +3,13 @@ from typing import List
 
 import typer
 
+from globus_automate_client.cli.callbacks import (
+    principal_validator_callback,
+    text_validator_callback,
+)
+from globus_automate_client.cli.helpers import format_and_echo, verbosity_option
 from globus_automate_client.queues_client import create_queues_client
-
-from .callbacks import principal_validator_callback, text_validator_callback
-from .helpers import CLIENT_ID, format_and_echo, verbosity_option
+from globus_automate_client.token_management import CLIENT_ID
 
 
 class QueueRole(str, Enum):
@@ -141,7 +144,7 @@ def queue_receive(
     "receiver" role on the Queue to perform this action.
     """
     qc = create_queues_client(CLIENT_ID)
-    queue = qc.receieve_messages(queue_id, max_messages=max_messages)
+    queue = qc.receive_messages(queue_id, max_messages=max_messages)
     format_and_echo(queue, verbose=verbose)
 
 
